netapp_ontap.models.status API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.status`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StatusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Status object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET POST PATCH`

    Code corresponding to the status message. Code is 0 when the state is 'up'.

    Example: 6684732

  `message: str GET POST PATCH`

    Detailed description of the validation state if the state is 'down' or the response time of the DNS server if the state is 'up'.

  `name_server: str GET POST PATCH`

    The IP address of the DNS server. The address can be either an IPv4 or an IPv6 address.

    Example: 10.10.10.10

  `state: str GET POST PATCH`

    The validation status of the DNS server.

    Valid choices:

    - up
    - down